Pinguino IDE 12
===============


### Install from PyPI ###
```shell
pip install pyside
pip install requests
pip install pinguino
```


### Install from source code ###

```shell
git clone https://github.com/PinguinoIDE/pinguino-ide.git Pinguino12-dev
cd Pinguino12-dev
git checkout v12-dev
mv ~/.pinguino ~/.pinguino.copy
python pinguino.py
```
----
[Report Bugs](https://github.com/PinguinoIDE/pinguino-ide/issues)

